pro make_user_kml,web_path,filename,sitename,sitelat,sitelon
;---------------------------------------------------------------------
; This program will create the .kml file that a user can d/l to their
; local machine that will point to current.terra/aqua.kml, which
; resides on the SSEC GE server.  This only needs to be run if the
; web path or file names of the GE data changes, or if newer meta data
; is added for the users.
;
; INPUT:
;  web_path: The www address where current.terra.kml and
;  current.aqua.kml reside, must end with a '/'.
;
; OUTPUT:
;  A kml file that a user can d/l onto their machine so that they can
;  enjoy the SSEC MODIS GE products!
;
; KEYWORD:
;  filename - set to a modis swath jpeg name for a given day to write
;  out a downloadable file that points to the Terra or Aqua GE data
;  for that particluar day.
;
; HARDWIRED: The output it saved to ../kml/
;
; AUTHOR: Amato Evan - CIMSS/UW-Madison amatoe@ssec.wisc.edu
;---------------------------------------------------------------------

; Get satellite name and date

sat_name = strmid(filename,8,4) ;terr or aqua
if(sat_name eq 'terr')then sat_name = 'terra'
date = strmid(filename,strpos(filename,'.jpg')-7,7)

; Make the KML file for the current data

openw,u,sitename+'_MODIS_Today.kml',/get_lun

;write the opening lines
printf,u,'<?xml version="1.0" encoding="UTF-8"?>'
printf,u,'<kml xmlns="http://earth.google.com/kml/2.2">'
printf,u,'<Document>'

lon_string=string(float(sitelon), format='(f8.3)')
lat_string=string(float(sitelat), format='(f8.3)')

printf,u,'	<name>'+sitename+' MODIS Today; Current day</name>'
printf,u,'	<LookAt>'
printf,u,' 		<longitude>'+lon_string+'</longitude>'
printf,u,'		<latitude>'+lat_string+'</latitude>'
printf,u,' 		<altitude>10000000</altitude>'
printf,u,' 		<range>0.1</range>'
printf,u,' 		<tilt>0</tilt>'
printf,u,' 		<heading>0</heading>'
printf,u,'	</LookAt>'
printf,u,'	<styleUrl>#check</styleUrl>'
printf,u,'	<Style id="hideChildren">'
printf,u,'		<ListStyle> '
printf,u,' 			<listItemType>checkHideChildren</listItemType>'
printf,u,' 		</ListStyle>'
printf,u,' 	</Style>'
printf,u,'	<Style id="radioFolder">'
printf,u,' 		<ListStyle>'
printf,u,' 			<listItemType>radioFolder</listItemType>'
printf,u,'		</ListStyle>'
printf,u,'	</Style>'
printf,u,'	<NetworkLink>'
printf,u,'		<name>AQUA</name>'
printf,u,'		<visibility>0</visibility>'
printf,u,'		<styleUrl>#hideChildren</styleUrl>'
printf,u,'		<Link>'
printf,u,'	           <href>'+web_path+sitename+'.current.aqua.kml</href>'
printf,u,'                   <refreshMode>onInterval</refreshMode>'
printf,u,'                   <refreshInterval>600</refreshInterval>'
printf,u,'		</Link>'
printf,u,'	</NetworkLink>'
printf,u,'	<NetworkLink>'
printf,u,'		<name>TERRA</name>'
printf,u,'		<styleUrl>#hideChildren</styleUrl>'
printf,u,'		<Link>'
printf,u,'                   <href>'+web_path+sitename+'.current.terra.kml</href>'
printf,u,'                   <refreshMode>onInterval</refreshMode>'
printf,u,'                   <refreshInterval>600</refreshInterval>'
printf,u,'		</Link>'
printf,u,'	</NetworkLink>'
printf,u,'</Document>'
printf,u,'</kml>'

close,u
free_lun,u

;---------------------------------------------------------------------

; Make the KML file for the given day

out_file=sitename+'.'+date+'.'+sat_name+'.kml'
openw,u,out_file,/get_lun

;write the opening lines
printf,u,'<?xml version="1.0" encoding="UTF-8"?>'
printf,u,'<kml xmlns="http://earth.google.com/kml/2.2">'
printf,u,'    <NetworkLink>'
printf,u,'	<name>'+sitename+' MODIS Today; Day '+date+'</name>'
printf,u,'	<LookAt>'
printf,u,' 		<longitude>'+lon_string+'</longitude>'
printf,u,'		<latitude>'+lat_string+'</latitude>'
printf,u,' 		<altitude>10000000</altitude>'
printf,u,' 		<range>0.1</range>'
printf,u,' 		<tilt>0</tilt>'
printf,u,' 		<heading>0</heading>'
printf,u,'	</LookAt>'
printf,u,'       <Style>'
printf,u,'           <ListStyle>'
printf,u,'               <listItemType>checkHideChildren</listItemType>'
printf,u,'           </ListStyle>'
printf,u,'       </Style>'
printf,u,'       <Link>'
printf,u,'           <href>'+web_path+date+'/'+date+'.'+sat_name+'.kml</href>'
printf,u,'           <refreshMode>onInterval</refreshMode>'
printf,u,'           <refreshInterval>600</refreshInterval>'
printf,u,'       </Link>'
printf,u,'    </NetworkLink>'
printf,u,'</kml>'

close,u
free_lun,u

; Copy to current KML file (for this day only)
file_copy, out_file, sitename+'.current.'+sat_name+'.kml', /overwrite

end
;-------------------------------------------------------------
