pro modis_kml,kpath,template,info,count
;---------------------------------------------------------------------
; This program will create a kml file for one image/tile that is part
; of a super overlay.  This program is written to be called by
; make_image_tiles.pro.
;
; INPUT:
;  kpath - directory to write the kml file
;  template - for all images [super overlay index number, super 
;   overlay level, min lat, min lon, max lat, max lon]
;  info - template entry for the super overlay tile in question
;  count - number of the image/kml file of all that are processed
;
; OUTPUT:
;  count.kml - kml file for this super overlay image that contains
;  basic info about the image (coords, etc.) and points to the images
;  that are above and below is the super overlay hierarchy.
;
; AUTHOR: Amato Evan - CIMSS/UW-Madison amatoe@ssec.wisc.edu
;---------------------------------------------------------------------

;get the number of higher res. images to link to
index = where(template[*,0] eq info[0] + 1 and $
    template[*,1] ge info[1] and template[*,2] ge info[2] and $
    template[*,3] le info[3] and template[*,4] le info[4], n_subsets)

openw,u,kpath+'/'+strcompress(round(count),/remove_all)+'.kml',/get_lun

;write the opening lines
printf,u,'<?xml version="1.0" encoding="UTF-8"?>'
printf,u,'<kml xmlns="http://earth.google.com/kml/2.2">'
printf,u,'  <Document>'
printf,u,'    <Region>'
printf,u,'      <Lod>'
printf,u,'        <minLodPixels>128</minLodPixels><maxLodPixels>-1</maxLodPixels>'
printf,u,'      </Lod>'
printf,u,'      <LatLonAltBox>'
printf,u,'        <north>'+strcompress(info[3])+'</north>'
printf,u,'        <south>'+strcompress(info[1])+'</south>'
printf,u,'        <east>'+strcompress(info[4])+'</east>'
printf,u,'        <west>'+strcompress(info[2])+'</west>'
printf,u,'      </LatLonAltBox>'
printf,u,'    </Region>'

;get the kml file name for subsets
if(n_subsets gt 0)then begin
    kml_names = strarr(n_subsets)
    for i = 0, n_subsets-1 do kml_names[i]=strcompress(index[i],/remove_all)+'.kml'
endif

;loop through and link to sub-directories
for i = 0, n_subsets - 1 do begin
printf,u,'    <NetworkLink>'
printf,u,'      <name>'+strcompress(index[i],/remove_all)+'</name>'
printf,u,'      <Region>'
printf,u,'        <Lod>'
printf,u,'          <minLodPixels>128</minLodPixels><maxLodPixels>-1</maxLodPixels>'
printf,u,'        </Lod>'
printf,u,'        <LatLonAltBox>'
printf,u,'          <north>'+strcompress(template[index[i],3])+'</north>'
printf,u,'          <south>'+strcompress(template[index[i],1])+'</south>'
printf,u,'          <east>'+strcompress(template[index[i],4])+'</east>'
printf,u,'          <west>'+strcompress(template[index[i],2])+'</west>'
printf,u,'        </LatLonAltBox>'
printf,u,'      </Region>'
printf,u,'      <Link>'
printf,u,'        <href>'+strcompress(index[i],/remove_all)+'.kml</href>'
printf,u,'        <viewRefreshMode>onRegion</viewRefreshMode>'
printf,u,'      </Link>'
printf,u,'    </NetworkLink>'
endfor

;link to the image for this level and close
printf,u,'        <GroundOverlay>'
printf,u,'          <drawOrder>'+strcompress(round(info[0]+1))+'</drawOrder>'
printf,u,'          <Icon>'
printf,u,'            <href>'+strcompress(round(count),/remove_all)+'.jpg</href>'
printf,u,'          </Icon>'
printf,u,'          <LatLonBox>'
printf,u,'            <north>'+strcompress(info[3])+'</north>'
printf,u,'            <south>'+strcompress(info[1])+'</south>'
printf,u,'            <east>'+strcompress(info[4])+'</east>'
printf,u,'            <west>'+strcompress(info[2])+'</west>'
printf,u,'          </LatLonBox>'
printf,u,'        </GroundOverlay>'
printf,u,'      </Document>'
printf,u,'    </kml>'

close,u
free_lun,u

end
;-------------------------------------------------------------
