PRO WRITE_GLOBAL_METADATA, GEO_FILE, SAT, DATE, TIME, RES, DIR

;- Check arguments
if (n_params() ne 6) then message, 'Usage: WRITE_GLOBAL_METADATA, GEO_FILE, SAT, DATE, TIME, RES, DIR'
if (n_elements(geo_file) eq 0) then message, 'Argument GEO_FILE is undefined'
if (n_elements(sat) eq 0) then message, 'Argument SAT is undefined'
if (n_elements(date) eq 0) then message, 'Argument DATE is undefined'
if (n_elements(time) eq 0) then message, 'Argument TIME is undefined'
if (n_elements(res) eq 0) then message, 'Argument RES is undefined'
if (n_elements(dir) eq 0) then message, 'Argument DIR is undefined'

;- Get lat/lon data from geo file
hdfid = hdf_sd_start(geo_file)
hdf_sd_varread, hdfid, 'Latitude', lat
hdf_sd_varread, hdfid, 'Longitude', lon
hdf_sd_end, hdfid

;- Get lat/lon at middle of geo file
dims = size(lat, /dimensions)
lat_mid = lat[dims[0] / 2, dims[1] / 2]
lon_mid = lon[dims[0] / 2, dims[1] / 2]

;- Get locations of good lat/lon values
loc = where((lat ge -90.0) and (lon ge -180.0))

;- Get grid indices
latlon_to_gridindex, lat[loc], lon[loc], res, index

;- Get unique grid indices
index = index[uniq(index, sort(index))]

;- Convert indices to tile LL corner lat/lons
gridindex_to_latlon, index, res, lat_cnr, lon_cnr

;- Switch to output directory
cd, dir

;- Loop over each tile and write metadata file
for tile = 0, n_elements(index) - 1 do begin

  ;- Set metadata directory name for this tile (e.g., tile412)
  meta_dir = string(index[tile], format='("tile", i3.3)')

  ;- If directory does not exist, create it
  if (file_test(meta_dir, /directory) eq 0) then file_mkdir, meta_dir

  ;- Set metadata file name for this tile (e.g., tile412/tile412.terra.2008190.1415.dat)
  meta_file = meta_dir + '/' + string(index[tile], sat, date, time, $
    format='("tile", i3.3, ".", a, ".", i7.7, ".", i4.4, ".dat")')

  ;- Create metadata file
  openw, lun, meta_file, /get_lun

  ;- Compute UL and LR corner lat/lons
  ul_lat = lat_cnr[tile] + res
  ul_lon = lon_cnr[tile]
  lr_lat = lat_cnr[tile]
  lr_lon = lon_cnr[tile] + res

  ;- Write metadata
  printf, lun, sat, format='("SAT  = ", a)'   
  printf, lun, date, format='("DATE = ", i7)'  
  printf, lun, index[tile], format='("TILE = ", i4)'
  printf, lun, ul_lon, ul_lat, format='("OUL  = ", f9.3, ",", f9.3)'
  printf, lun, lr_lon, lr_lat, format='("OLR  = ", f9.3, ",", f9.3)'

  ;- Write granule time and filename
  printf, lun, time, lon_mid, lat_mid, format='(i4.4, " UTC: ", f9.3, ",", f9.3)'
  
  ;- Close metadata file
  free_lun, lun
  
  ;- Create event file name for this tile (e.g., tile412/tile412.terra.2008190.1415.event)
  event_file = meta_dir + '/' + string(index[tile], sat, date, time, $
    format='("tile", i3.3, ".", a, ".", i7.7, ".", i4.4, ".event")')

  ;- Create event file
  openw, lun, event_file, /get_lun
  printf, lun, ""
  free_lun, lun
  
endfor

END
