#!/bin/bash

# Create a MODIS true color reprojected image given corrected reflectance input files
# Usage: run_modis_reproject.bash fil_geo ref_hkm ref_qkm oul olr fil_out

# Startup message
echo "Started "$0" at "`date`

# Check for DBGE_HOME environment variable
if [ -z "$DBGE_HOME" ]; then
  echo "Environment variable DBGE_HOME is not set"
  exit 1
fi

# Get arguments
fil_geo=$1
ref_hkm=$2
ref_qkm=$3
oul=$4
olr=$5
fil_out=$6

# Setup MRTSwath environment
export MRTDATADIR=$DBGE_HOME/bin/mrtdatadir

# Reproject band 1: QKM input -> 250 meter HDF output
out_qkm="PROJ_"$ref_qkm
$DBGE_HOME/bin/swath2grid -if=$ref_qkm -gf=$fil_geo -oul="$oul" -olr="$olr" \
  -oproj="EQRECT" -kk=CC -osp=8 -opsz=250.0 -of=$out_qkm -off=HDF_FMT  \
  -sds="CorrRefl_01"
result=$?

# Check status
if [ $result -ne 0 ]; then
  echo "Error in MRTSwath QKM processing"
  exit 1
fi

# Reproject bands 1,4,3: HKM input -> 250 meter HDF output
out_hkm="PROJ_"$ref_hkm
$DBGE_HOME/bin/swath2grid -if=$ref_hkm -gf=$fil_geo -oul="$oul" -olr="$olr" \
  -oproj="EQRECT" -kk=CC -osp=8 -opsz=250.0 -of=$out_hkm -off=HDF_FMT  \
  -sds="CorrRefl_01; CorrRefl_03; CorrRefl_04"
result=$?

# Check status
if [ $result -ne 0 ]; then
  echo "Error in MRTSwath HKM processing"
  exit 1
fi

# Run IDL script to create TIFF image
echo "modis_reproject, '"$out_qkm"', '"$out_hkm"', '"$fil_out"'" > runidl
echo "exit" >> runidl
cat runidl
idl runidl

# Check status
if [ $result -ne 0 ]; then
  echo "Error in IDL image processing"
  exit 1
fi

# Cleanup
/bin/rm -f $out_qkm $out_hkm patches.tmp????? tmp??????

# Exit
echo
echo "Finished "$0" at "`date`
exit 0
